==> decorators-3.23.0.tgz: package/lib/decorators/cache/algorithms/Redis.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import Cache from './Cache';
import RedisClient from './RedisClient';
import lru from 'redis-lru';

var Redis = /*#__PURE__*/function (_Cache) {
  _inheritsLoose(Redis, _Cache);

  function Redis(_temp) {
    var _this;

    var _ref = _temp === void 0 ? {} : _temp,
        _ref$redisConnection = _ref.redisConnection,
        redisConnection = _ref$redisConnection === void 0 ? {
      host: '127.0.0.1',
      port: 6379
    } : _ref$redisConnection,
        _ref$size = _ref.size,
        size = _ref$size === void 0 ? 100 : _ref$size,
        namespace = _ref.namespace,
        _ref$ttl = _ref.ttl,
        ttl = _ref$ttl === void 0 ? 500 : _ref$ttl;

    _this = _Cache.call(this) || this;
    _this._ttl = ttl;
    _this._redisClient = RedisClient.getInstance({
      redisConnection: redisConnection
    }).client;
    _this._lruRedis = lru(_this._redisClient, {
      max: size,
      namespace: namespace
    });
    return _this;
  }

  var _proto = Redis.prototype;

  _proto._delay = function _delay(ms) {
    return new Promise(function (resolve) {
      setTimeout(function () {
        return resolve();
      }, ms);
    });
  };

  _proto.get = /*#__PURE__*/function () {
    var _get = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(key) {
      var resp;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;
              _context.next = 3;
              return Promise.race([this._lruRedis.get(key), this._delay(100)]);

            case 3:
              resp = _context.sent;
              return _context.abrupt("return", resp);

            case 7:
              _context.prev = 7;
              _context.t0 = _context["catch"](0);
              console.error("[sui-decorators/cache]:Redis Error Getting cache item for key: " + key + ".", _context.t0.message);
              return _context.abrupt("return", null);

            case 11:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this, [[0, 7]]);
    }));

    function get(_x) {
      return _get.apply(this, arguments);
    }

    return get;
  }()
  /**
   *
   * @param {string} key
   * @param {string} value
   * @param {number} maxAge expire time in ms, default = 500ms
   */
  ;

  _proto.set = function set(key, value, maxAge) {
    if (maxAge === void 0) {
      maxAge = this._ttl;
    }

    var ret = this._lruRedis.set(key, value, maxAge);

    Promise.race([ret, this._delay(100)])["catch"](function (err) {
      console.error("[sui-decorators/cache]:Redis Error Setting cache item for key: " + key + ".", err.message);
    });
  };

  _proto.del = function del(key) {
    try {
      this._lruRedis.del(key);
    } catch (err) {
      console.error("[sui-decorators/cache]:Redis Error deleting cache item for key: " + key + ".", err.message);
    }
  };

  _proto.clear = function clear() {
    this._lruRedis.reset();
  };

  return Redis;
}(Cache);

export { Redis as default };

==> decorators-3.25.0.tgz: package/lib/decorators/cache/algorithms/Redis.js <==
import _asyncToGenerator from "@babel/runtime/helpers/esm/asyncToGenerator";
import _inheritsLoose from "@babel/runtime/helpers/esm/inheritsLoose";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import lru from 'redis-lru';
import Cache from './Cache.js';
import RedisClient from './RedisClient.js';

var Redis = /*#__PURE__*/function (_Cache) {
  _inheritsLoose(Redis, _Cache);

  function Redis(_temp) {
    var _this;

    var _ref = _temp === void 0 ? {} : _temp,
        _ref$redisConnection = _ref.redisConnection,
        redisConnection = _ref$redisConnection === void 0 ? {
      host: '127.0.0.1',
      port: 6379
    } : _ref$redisConnection,
        _ref$size = _ref.size,
        size = _ref$size === void 0 ? 100 : _ref$size,
        namespace = _ref.namespace,
        _ref$ttl = _ref.ttl,
        ttl = _ref$ttl === void 0 ? 500 : _ref$ttl;

    _this = _Cache.call(this) || this;
    _this._ttl = ttl;
    _this._redisClient = RedisClient.getInstance({
      redisConnection: redisConnection
    }).client;
    _this._lruRedis = lru(_this._redisClient, {
      max: size,
      namespace: namespace
    });
    return _this;
  }

  var _proto = Redis.prototype;

  _proto._delay = function _delay(ms) {
    return new Promise(function (resolve) {
      setTimeout(function () {
        return resolve();
      }, ms);
    });
  };

  _proto.get = /*#__PURE__*/function () {
    var _get = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(key) {
      var resp;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) {
          switch (_context.prev = _context.next) {
            case 0:
              _context.prev = 0;
              _context.next = 3;
              return Promise.race([this._lruRedis.get(key), this._delay(100)]);

            case 3:
              resp = _context.sent;
              return _context.abrupt("return", resp);

            case 7:
              _context.prev = 7;
              _context.t0 = _context["catch"](0);
              console.error("[sui-decorators/cache]:Redis Error Getting cache item for key: " + key + ".", _context.t0.message);
              return _context.abrupt("return", null);

            case 11:
            case "end":
              return _context.stop();
          }
        }
      }, _callee, this, [[0, 7]]);
    }));

    function get(_x) {
      return _get.apply(this, arguments);
    }

    return get;
  }()
  /**
   *
   * @param {string} key
   * @param {string} value
   * @param {number} maxAge expire time in ms, default = 500ms
   */
  ;

  _proto.set = function set(key, value, maxAge) {
    if (maxAge === void 0) {
      maxAge = this._ttl;
    }

    var ret = this._lruRedis.set(key, value, maxAge);

    Promise.race([ret, this._delay(100)]).catch(function (err) {
      console.error("[sui-decorators/cache]:Redis Error Setting cache item for key: " + key + ".", err.message);
    });
  };

  _proto.del = function del(key) {
    try {
      this._lruRedis.del(key);
    } catch (err) {
      console.error("[sui-decorators/cache]:Redis Error deleting cache item for key: " + key + ".", err.message);
    }
  };

  _proto.clear = function clear() {
    this._lruRedis.reset();
  };

  return Redis;
}(Cache);

export { Redis as default };
